var searchData=
[
  ['tablet_20events',['Tablet events',['../group__event__tablet.html',1,'']]],
  ['touch_20events',['Touch events',['../group__event__touch.html',1,'']]],
  ['t440_2dsupport_2edox',['t440-support.dox',['../t440-support_8dox.html',1,'']]],
  ['tablet_20support',['Tablet support',['../tablet-support.html',1,'tablets']]],
  ['tablet_2dsupport_2edox',['tablet-support.dox',['../tablet-support_8dox.html',1,'']]],
  ['tap_2dto_2dclick_20behaviour',['Tap-to-click behaviour',['../tapping.html',1,'touchpads']]],
  ['tapping_2edox',['tapping.dox',['../tapping_8dox.html',1,'']]],
  ['test_2dsuite_2edox',['test-suite.dox',['../test-suite_8dox.html',1,'']]],
  ['tools_2edox',['tools.dox',['../tools_8dox.html',1,'']]],
  ['touchpads',['Touchpads',['../touchpads.html',1,'']]],
  ['touchpads_2edox',['touchpads.dox',['../touchpads_8dox.html',1,'']]],
  ['touchscreens',['Touchscreens',['../touchscreens.html',1,'']]]
];
